@@ -1054,7 +1054,6 @@ struct grib_context
     int                             ieee_packing;
     int                             bufrdc_mode;
     int                             bufr_set_to_missing_if_out_of_range;
-    int                             bufr_quality_without_bitmap;
     FILE*                           log_stream;
     grib_trie*                      classes;
     grib_trie*                      lists;
@@ -1386,7 +1385,7 @@ struct bufr_keys_iterator{
   unsigned long     accessor_flags_skip;
   unsigned long     accessor_flags_only;
   grib_accessor*    current;
-  grib_string_list* names;
+  char*             key_name;
   int               at_start;
   int               match;
   int               i_curr_attribute;
