@@ -243,24 +243,36 @@ static void dump_long(grib_dumper* d,grib_accessor* a,const char* comment)
     }
 
     if (size>1) {
+        int doing_unexpandedDescriptors=0;
         int icount=0;
         if (self->isLeaf==0) {
             fprintf(self->dumper.out,"%-*s",depth," ");
             fprintf(self->dumper.out,"\"value\" :\n");
         }
         fprintf(self->dumper.out,"%-*s[",depth," ");
+        /* See ECC-637: unfortunately json_xs says:
+         *  malformed number (leading zero must not be followed by another digit
+          if (strcmp(a->name, "unexpandedDescriptors")==0)
+            doing_unexpandedDescriptors = 1;
+          */
         depth+=2;
         for (i=0;i<size-1;i++) {
             if (icount>cols || i==0) {fprintf(self->dumper.out,"\n%-*s",depth," ");icount=0;}
             if (grib_is_missing_long(a,values[i])) {
                 fprintf(self->dumper.out,"null, ");
             } else {
-                fprintf(self->dumper.out,"%ld, ",values[i]);
+                if (doing_unexpandedDescriptors)
+                    fprintf(self->dumper.out,"%06ld, ",values[i]);
+                else
+                    fprintf(self->dumper.out,"%ld, ",values[i]);
             }
             icount++;
         }
         if (icount>cols) fprintf(self->dumper.out,"\n%-*s",depth," ");
-        fprintf(self->dumper.out,"%ld ",values[i]);
+        if (doing_unexpandedDescriptors)
+            fprintf(self->dumper.out,"%06ld ",values[i]);
+        else
+            fprintf(self->dumper.out,"%ld ",values[i]);
 
         depth-=2;
         fprintf(self->dumper.out,"\n%-*s]",depth," ");
@@ -399,34 +411,38 @@ static void dump_string_array(grib_dumper* d,grib_accessor* a,const char* commen
     (void)err; /* TODO */
 }
 
+# define MAX_STRING_SIZE 4096
 static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
 {
     grib_dumper_json *self = (grib_dumper_json*)d;
-    char *value = NULL;
+    char value[MAX_STRING_SIZE] = {0,};  /* See ECC-710 */
     char *p = NULL;
-    size_t size = 0;
+    size_t size = MAX_STRING_SIZE;
     int is_missing = 0;
-    grib_context* c = NULL;
-    int err = _grib_get_string_length(a,&size);
+    int err = 0;
 
-    c = a->context;
-    if (size==0) return;
-
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
-        return;
-
-    value=(char*)grib_context_malloc_clear(c,size);
-    if (!value) {
-        grib_context_log(c,GRIB_LOG_FATAL,"unable to allocate %d bytes",(int)size);
+    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0) {
         return;
     }
 
+    /* ECC-710: It is MUCH slower determining the string length here
+     * than using a maximum size (and no need for malloc).
+     * Specially for BUFR elements */
+    /*err = _grib_get_string_length(a,&size);
+    if (size==0) return;
+    value=(char*)grib_context_malloc_clear(a->context,size);
+    if (!value) {
+        grib_context_log(a->context,GRIB_LOG_FATAL,"unable to allocate %d bytes",(int)size);
+        return;
+    }*/
+
     if (self->begin==0 && self->empty==0 && self->isAttribute==0) fprintf(self->dumper.out,",");
     else self->begin=0;
 
     self->empty=0;
 
     err = grib_unpack_string(a,value,&size);
+    Assert(size < MAX_STRING_SIZE);
     p=value;
     if (grib_is_missing_string(a,(unsigned char *)value,size)) {
         is_missing = 1;
@@ -453,7 +469,7 @@ static void dump_string(grib_dumper* d,grib_accessor* a,const char* comment)
         fprintf(self->dumper.out,"\n%-*s}",depth," ");
     }
 
-    grib_context_free(c,value);
+    /*grib_context_free(a->context,value);*/
     (void)err; /* TODO */
 }
 
