@@ -832,7 +832,7 @@ void grib_print_key_values(grib_runtime_options* options, grib_handle* h)
     double dvalue=0;
     long lvalue=0;
     char value[MAX_STRING_LEN];
-    char* notfound="not_found";
+    const char* notfound="not_found";
     int written_to_dump = 0; /* boolean */
     grib_accessor* acc = NULL;
 
@@ -1112,3 +1112,15 @@ void grib_tools_write_message(grib_runtime_options* options, grib_handle* h)
 #endif
 
 }
+int exit_if_input_is_directory(const char* tool_name, const char* filename)
+{
+    struct stat s;
+    int stat_val = stat(filename, &s);
+    if ( stat_val == 0 ) {
+        if (S_ISDIR(s.st_mode)) {
+            fprintf(stderr, "%s: ERROR: \"%s\": Is a directory\n", tool_name, filename);
+            exit(1);
+        }
+    }
+    return 0;
+}
